Summary: Zsh is a shell designed for interactive use, also a powerful scripting language
Name:    zsh
Version: 5.8.1
Release: 11%{?dist}
License: MIT
URL:     https://zsh.sourceforge.io/
Source0: https://sourceforge.net/projects/%{name}/files/%{name}/%{version}/%{name}-%{version}.tar.xz
# startup files from https://zsh.sourceforge.io/Intro/intro_3.html#SEC3
Source1: zshenv
Source2: zprofile
Source3: zshrc
Source4: zlogin
Source5: zlogout
Source6: dotzshrc

Patch0001: 0001-45470-C02cond-Simplify-N-cond-test.patch
Patch5000: 5000-Do-not-use-egrep-in-E01options-ztst.patch
Patch5001: 5001-fix-sql-query-error.patch

BuildRequires: autoconf gcc make coreutils gawk sed
BuildRequires: gdbm-devel ncurses-devel pcre-devel texinfo
Requires(post): grep
Requires(postun): coreutils grep

Provides: /bin/zsh

%description
Zsh is a shell designed for interactive use, although it is also a powerful scripting language. 
Many of the useful features of bash, ksh, and tcsh were incorporated into zsh; 
many original features were added.
Please install zsh-doc for man and info.

%package              doc
Summary:              zsh shell manual including man and info
BuildArch:            noarch

%description          doc
This package contains the zsh manual including man and info.

%prep
%autosetup -p1
autoreconf -fiv

# enable parallel build
sed -i -e 's|^\.NOTPARALLEL|#.NOTPARALLEL|' 'Config/defs.mk.in'

%build
%undefine _strict_symbol_defs_build
export LIBLDFLAGS='-z lazy'
%configure --enable-etcdir=%{_sysconfdir} --with-tcsetpgrp --enable-maildir-support --enable-pcre

make -C Src headers
make -C Src -f Makemod zsh{path,xmod}s.h version.h
%make_build all html

%check
make check

%install
%make_install install.info fndir=%{_datadir}/%{name}/%{version}/functions sitefndir=%{_datadir}/%{name}/site-functions \
                           scriptdir=%{_datadir}/%{name}/%{version}/scripts sitescriptdir=%{_datadir}/%{name}/scripts \
                           runhelpdir=%{_datadir}/%{name}/%{version}/help

rm -f $RPM_BUILD_ROOT%{_bindir}/zsh-%{version}
rm -f $RPM_BUILD_ROOT%{_infodir}/dir

mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}
for i in %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4} %{SOURCE5}; do
    install -m 644 $i $RPM_BUILD_ROOT%{_sysconfdir}/"${i##*/}"
done

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/skel
install -m 644 %{SOURCE6} $RPM_BUILD_ROOT%{_sysconfdir}/skel/.zshrc

for i in checkmail harden run-help zcalc zkbd; do
    sed -i -e 's|/usr/local/bin/zsh|%{_bindir}/zsh|' $RPM_BUILD_ROOT%{_datadir}/zsh/%{version}/functions/$i
    chmod +x $RPM_BUILD_ROOT%{_datadir}/zsh/%{version}/functions/$i
done

%post
if [ "$1" = 1 ]; then
  if [ ! -f %{_sysconfdir}/shells ] ; then
    echo "%{_bindir}/%{name}" > %{_sysconfdir}/shells
    echo "/bin/%{name}" >> %{_sysconfdir}/shells
  else
    grep -q "^%{_bindir}/%{name}$" %{_sysconfdir}/shells || echo "%{_bindir}/%{name}" >> %{_sysconfdir}/shells
    grep -q "^/bin/%{name}$" %{_sysconfdir}/shells || echo "/bin/%{name}" >> %{_sysconfdir}/shells
  fi
fi

%postun
if [ "$1" = 0 ] && [ -f %{_sysconfdir}/shells ] ; then
  sed -i '\|^%{_bindir}/%{name}$|d' %{_sysconfdir}/shells
  sed -i '\|^/bin/%{name}$|d' %{_sysconfdir}/shells
fi


%files
%license LICENCE
%doc README Etc/* FEATURES MACHINES NEWS
%attr(755,root,root) %{_bindir}/zsh
%{_libdir}/zsh
%{_datadir}/zsh
%config(noreplace) %{_sysconfdir}/skel/.z*
%config(noreplace) %{_sysconfdir}/z*

%files doc
%license LICENCE
%doc Doc/*.html
%{_mandir}/*/*
%{_infodir}/*


%changelog
* Mon Jun 09 2025 licunlong <cunlongli@tencent.com> - 5.8.1-11
- Disabling PPROMPT, as the right-side prompt may cause confusion for users

* Thu Nov 07 2024 Xinlong Chen <xinlongchen@tencent.com> - 5.8.1-10
- fix 'dnf install <tab>' error

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8.1-9
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8.1-8
- Rebuilt for loongarch release

* Mon Sep 11 2023 kianli <kianli@tencent.com> - 5.8.1-7
- Do not use egrep in tests

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8.1-6
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Jun 08 2023 kianli <kianli@tencent.com> - 5.8.1-5
- Fix C02cond test fail

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8.1-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8.1-3
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 15 2023 rockerzhu <rockerzhu@tencent.com> - 5.8.1-2
- Fix postun scriptlets fail.

* Sat Apr 16 2022 rockerzhu <rockerzhu@tencent.com> - 5.8.1-1
- Initial build
